/*
 * Copyright (c) 2018, Mellanox Technologies. All rights reserved.
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#ifndef __MLX_PERF_EVENTS_H__
#define __MLX_PERF_EVENTS_H__

struct perf_events {
	uint32_t evt_num;
	char *evt_name;
};

struct perf_events pcie_events[] = {
{0x0,  "IN_P_PKT_CNT"},
{0x10, "IN_NP_PKT_CNT"},
{0x18, "IN_C_PKT_CNT"},
{0x20, "OUT_P_PKT_CNT"},
{0x28, "OUT_NP_PKT_CNT"},
{0x30, "OUT_C_PKT_CNT"},
{0x38, "IN_P_BYTE_CNT"},
{0x40, "IN_NP_BYTE_CNT"},
{0x48, "IN_C_BYTE_CNT"},
{0x50, "OUT_P_BYTE_CNT"},
{0x58, "OUT_NP_BYTE_CNT"},
{0x60, "OUT_C_BYTE_CNT"},
{-1, NULL}
};

struct perf_events triogen_events[] = {
{0x0,  "AW_REQ"},
{0x1,  "AW_BEATS"},
{0x2,  "AW_TRANS"},
{0x3,  "AW_RESP"},
{0x4,  "AW_STL"},
{0x5,  "AW_LAT"},
{0x6,  "AW_REQ_TBU"},
{0x8,  "AR_REQ"},
{0x9,  "AR_BEATS"},
{0xa,  "AR_TRANS"},
{0xb,  "AR_STL"},
{0xc,  "AR_LAT"},
{0xd,  "AR_REQ_TBU"},
{0xe,  "TBU_MISS"},
{0xf,  "TX_DAT_AF"},
{0x10, "RX_DAT_AF"},
{0x11, "RETRYQ_CRED"},
{-1, NULL}
};

struct perf_events trio_events[] = {
{0xa0, "TPIO_DATA_BEAT"},
{0xa1, "TDMA_DATA_BEAT"},
{0xa2, "MAP_DATA_BEAT"},
{0xa3, "TXMSG_DATA_BEAT"},
{0xa4, "TPIO_DATA_PACKET"},
{0xa5, "TDMA_DATA_PACKET"},
{0xa6, "MAP_DATA_PACKET"},
{0xa7, "TXMSG_DATA_PACKET"},
{0xa8, "TDMA_RT_AF"},
{0xa9, "TDMA_PBUF_MAC_AF"},
{0xaa, "TRIO_MAP_WRQ_BUF_EMPTY"},
{0xab, "TRIO_MAP_CPL_BUF_EMPTY"},
{0xac, "TRIO_MAP_RDQ0_BUF_EMPTY"},
{0xad, "TRIO_MAP_RDQ1_BUF_EMPTY"},
{0xae, "TRIO_MAP_RDQ2_BUF_EMPTY"},
{0xaf, "TRIO_MAP_RDQ3_BUF_EMPTY"},
{0xb0, "TRIO_MAP_RDQ4_BUF_EMPTY"},
{0xb1, "TRIO_MAP_RDQ5_BUF_EMPTY"},
{0xb2, "TRIO_MAP_RDQ6_BUF_EMPTY"},
{0xb3, "TRIO_MAP_RDQ7_BUF_EMPTY"},
{-1, NULL}
};

struct perf_events ecc_events[] = {
{0x100, "ECC_SINGLE_ERROR_CNT"},
{0x104, "ECC_DOUBLE_ERROR_CNT"},
{0x114, "SERR_INJ"},
{0x118, "DERR_INJ"},
{0x124, "ECC_SINGLE_ERROR_0"},
{0x164, "ECC_DOUBLE_ERROR_0"},
{0x340, "DRAM_ECC_COUNT"},
{0x344, "DRAM_ECC_INJECT"},
{0x348, "DRAM_ECC_ERROR",},
{-1, NULL}
};

struct perf_events mss_events[] = {
{0xc0, "RXREQ_MSS"},
{0xc1, "RXDAT_MSS"},
{0xc2, "TXRSP_MSS"},
{0xc3, "TXDAT_MSS"},
{-1, NULL}
};

struct perf_events hnf_events[] = {
{0x45, "HNF_REQUESTS"},
{0x46, "HNF_REJECTS"},
{0x47, "ALL_BUSY"},
{0x48, "MAF_BUSY"},
{0x49, "MAF_REQUESTS"},
{0x4a, "RNF_REQUESTS"},
{0x4b, "REQUEST_TYPE"},
{0x4c, "MEMORY_READS"},
{0x4d, "MEMORY_WRITES"},
{0x4e, "VICTIM_WRITE"},
{0x4f, "POC_FULL"},
{0x50, "POC_FAIL"},
{0x51, "POC_SUCCESS"},
{0x52, "POC_WRITES"},
{0x53, "POC_READS"},
{0x54, "FORWARD"},
{0x55, "RXREQ_HNF"},
{0x56, "RXRSP_HNF"},
{0x57, "RXDAT_HNF"},
{0x58, "TXREQ_HNF"},
{0x59, "TXRSP_HNF"},
{0x5a, "TXDAT_HNF"},
{0x5b, "TXSNP_HNF"},
{0x5c, "INDEX_MATCH"},
{0x5d, "A72_ACCESS"},
{0x5e, "IO_ACCESS"},
{0x5f, "TSO_WRITE"},
{0x60, "TSO_CONFLICT"},
{0x61, "DIR_HIT"},
{0x62, "HNF_ACCEPTS"},
{0x63, "REQ_BUF_EMPTY"},
{0x64, "REQ_BUF_IDLE_MAF"},
{0x65, "TSO_NOARB"},
{0x66, "TSO_NOARB_CYCLES"},
{0x67, "MSS_NO_CREDIT"},
{0x68, "TXDAT_NO_LCRD"},
{0x69, "TXSNP_NO_LCRD"},
{0x6a, "TXRSP_NO_LCRD"},
{0x6b, "TXREQ_NO_LCRD"},
{0x6c, "TSO_CL_MATCH"},
{0x6d, "MEMORY_READS_BYPASS"},
{0x6e, "TSO_NOARB_TIMEOUT"},
{0x6f, "ALLOCATE"},
{0x70, "VICTIM"},
{0x71, "A72_WRITE"},
{0x72, "A72_Read"},
{0x73, "IO_WRITE"},
{0x74, "IO_READ"},
{0x75, "TSO_REJECT"},
{0x80, "TXREQ_RN"},
{0x81, "TXRSP_RN"},
{0x82, "TXDAT_RN"},
{0x83, "RXSNP_RN"},
{0x84, "RXRSP_RN"},
{0x85, "RXDAT_RN"},
{-1, NULL}
};

struct perf_events l3cache_events[] = {
{0x00, "DISABLE"},
{0x01, "CYCLES"},
{0x02, "TOTAL_RD_REQ_IN"},
{0x03, "TOTAL_WR_REQ_IN"},
{0x04, "TOTAL_WR_DBID_ACK"},
{0x05, "TOTAL_WR_DATA_IN"},
{0x06, "TOTAL_WR_COMP"},
{0x07, "TOTAL_RD_DATA_OUT"},
{0x08, "TOTAL_CDN_REQ_IN_BANK0"},
{0x09, "TOTAL_CDN_REQ_IN_BANK1"},
{0x0a, "TOTAL_DDN_REQ_IN_BANK0"},
{0x0b, "TOTAL_DDN_REQ_IN_BANK1"},
{0x0c, "TOTAL_EMEM_RD_RES_IN_BANK0"},
{0x0d, "TOTAL_EMEM_RD_RES_IN_BANK1"},
{0x0e, "TOTAL_CACHE_RD_RES_IN_BANK0"},
{0x0f, "TOTAL_CACHE_RD_RES_IN_BANK1"},
{0x10, "TOTAL_EMEM_RD_REQ_BANK0"},
{0x11, "TOTAL_EMEM_RD_REQ_BANK1"},
{0x12, "TOTAL_EMEM_WR_REQ_BANK0"},
{0x13, "TOTAL_EMEM_WR_REQ_BANK1"},
{0x14, "TOTAL_RD_REQ_OUT"},
{0x15, "TOTAL_WR_REQ_OUT"},
{0x16, "TOTAL_RD_RES_IN"},
{0x17, "HITS_BANK0"},
{0x18, "HITS_BANK1"},
{0x19, "MISSES_BANK0"},
{0x1a, "MISSES_BANK1"},
{0x1b, "ALLOCATIONS_BANK0"},
{0x1c, "ALLOCATIONS_BANK1"},
{0x1d, "EVICTIONS_BANK0"},
{0x1e, "EVICTIONS_BANK1"},
{0x1f, "DBID_REJECT"},
{0x20, "WRDB_REJECT_BANK0"},
{0x21, "WRDB_REJECT_BANK1"},
{0x22, "CMDQ_REJECT_BANK0"},
{0x23, "CMDQ_REJECT_BANK1"},
{0x24, "COB_REJECT_BANK0"},
{0x25, "COB_REJECT_BANK1"},
{0x26, "TRB_REJECT_BANK0"},
{0x27, "TRB_REJECT_BANK1"},
{0x28, "TAG_REJECT_BANK0"},
{0x29, "TAG_REJECT_BANK1"},
{0x2a, "ANY_REJECT_BANK0"},
{0x2b, "ANY_REJECT_BANK1"},
{-1, NULL}
};

#endif /* __MLX_PERF_EVENTS_H__ */
